@@ -6,7 +6,7 @@ Created on Various Days
 
 """
 
-from TOpsPy.Modeling.GmTVector import *
+from topspy.modeling.GmTVector import *
  
     
     
